import {
  applyMiddleware,
  compose,
  createStore,
  Store,
} from 'redux';
import { routerMiddleware } from 'react-router-redux';
import createSagaMiddleware, {
  SagaMiddleware,
} from 'redux-saga';

import {
  createHashHistory,
  History,
} from 'history';

import {
  EnhancerOptions,
  composeWithDevTools,
} from 'redux-devtools-extension/logOnlyInProduction';

import reduxLogger from 'redux-logger';

import reducer from './reducer';
import State from './state';

const useReduxDevTools = window.devToolsExtension && process.env.NODE_ENV !== 'production' ? true : false;


const history = createHashHistory();
const sagaMiddleware: SagaMiddleware<any> = createSagaMiddleware();
const middlewares = [sagaMiddleware, routerMiddleware(history)];

const store: Store<State> = createStore<State>(
    reducer,
    useReduxDevTools ?
      compose(
        applyMiddleware(...middlewares),
        window.devToolsExtension(),
      )
      :
      applyMiddleware(...middlewares),
);

export {
  history,
  sagaMiddleware,
  store,
};
