import * as React from 'react';
import { Redirect, RouteComponentProps, RouteProps, Route, Switch } from 'react-router-dom';
import { Container, Menu, Sidebar, Segment, Icon, Breadcrumb, Grid, Dropdown } from 'semantic-ui-react';
import { Header } from './Header';
import { Footer } from './Footer';
import  TitleBarContainer from './TitleBarContainer';
import LeftMenu from './LeftMenu';

import Home from '../Home';
import ProbeList from '../../views/monitoring/probe/List';
import TargetList from '../../views/infrastructure/target/List';
import SensorList from '../monitoring/sensor/List';

export interface Props extends RouteComponentProps<any> {
}
export interface State {
  sidebar_visible: boolean;
  notification_visible: boolean;
}

export class AppLayout extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      sidebar_visible: true,
      notification_visible: false,
    };
  }

  public onSidebar = () => {
    this.setState({ notification_visible: !this.state.notification_visible, sidebar_visible: !this.state.sidebar_visible });
  }

  public render(): JSX.Element {
    return (
      <Container fluid>
        <LeftMenu />
        <Segment vertical style={{ margin: '0 0 0 210px', padding: '0' }}>
          <Header />
          <TitleBarContainer />
            <Switch>
              <Route exact={true} path={`${this.props.match.url}`} component={Home}/>
              <Route exact={true} path={`${this.props.match.url}probes`} component={ProbeList}/>
              <Route exact={true} path={`${this.props.match.url}targets`} component={TargetList}/>
              <Route exact={true} path={`${this.props.match.url}sensors`} component={SensorList}/>
              <Redirect to='/error/404' />
            </Switch>
          <Footer />
        </Segment>
      </Container >
    );
  }
}

export default AppLayout;

